@@ -177,6 +177,31 @@ private:
     int findDomElement(const QString &domStr, const QString &element, int pos,
                        bool &isNewStart);
 
+    // QT4 / QT5 JSON handlers
+    bool onGetPhonesQtX(AsyncTaskToken *token, const QString &json);
+    bool parseInboxJsonQtX(AsyncTaskToken *token, const QString &strJson,
+                           const QString &strHtml, qint32 &msgCount);
+
+    void validateAndMatchInboxEntry(GVInboxEntry &inboxEntry,
+                                    AsyncTaskToken *token,
+                                    const QString &strHtml);
+
+    bool onCalloutX(const QString &json, QString &accessNumber);
+    bool onCallbackX(const QString &json, quint32 &code, QString &errMsg);
+    bool checkJsonForOk(const QString &json);
+    bool onSendSmsX(const QString &json);
+    bool onCheckRecentInboxX(const QString &json, quint32 &totalSize,
+                             QDateTime &serverLatest);
+
+    void inline
+    warnAndLog(const QString &msg, const QString &json)
+    {
+        Q_WARN(msg);
+        if (emitLog) {
+            Q_DEBUG("JSON Data from GV:") << json;
+        }
+    }
+
 private:
     bool emitLog;
 
@@ -190,8 +215,6 @@ private:
     QVariantMap hiddenLoginFields;
 
     bool dbgAlwaysFailDialing;
-
-    QScriptEngine scriptEngine;
 };
 
 #endif // GVAPI_H
