@@ -31,6 +31,7 @@ Contact: yuvraaj@gmail.com
 #include "LibGvPhones.h"
 #include "LogUploader.h"
 #include "LibVmail.h"
+#include "Mixpanel.h"
 
 /*==============================================================================
  *
@@ -231,6 +232,8 @@ protected:
     QVector <LogMessage> m_logMessages;
     QTimer      m_logMessageTimer;
 
+    MixPanel    m_mixPanel;
+
     friend class LibContacts;
     friend class LibInbox;
     friend class LibGvPhones;
