@@ -51,7 +51,7 @@ protected slots:
     void uiClearStatusMessage();
     void uiShowMessageBox(const QString &msg);
 
-    void onLoginButtonClicked();
+    Q_INVOKABLE void onLoginButtonClicked();
 
     void onSigProxyChanges(bool enable, bool useSystemProxy, QString server,
                            int port, bool authRequired, QString user,
@@ -71,16 +71,14 @@ protected slots:
     void onVmailDurationChanged(quint64 duration);
     void onVmailCurrentPositionChanged(quint64 position, quint64 duration);
 
-    void onOptContactsUpdateClicked(bool updateDb = true);
-    void onOptInboxUpdateClicked(bool updateDb = true);
+    Q_INVOKABLE void onOptContactsUpdateClicked(bool updateDb = true);
+    Q_INVOKABLE void onOptInboxUpdateClicked(bool updateDb = true);
 
-    void onEdContactsUpdateTextChanged();
-    void onEdInboxUpdateTextChanged();
+    Q_INVOKABLE void onEdContactsUpdateTextChanged(const QString &text);
+    Q_INVOKABLE void onEdInboxUpdateTextChanged(const QString &text);
 
 protected:
     QObject *getQMLObject(const char *pageName);
-    bool connectToChangeNotify(QObject *item, const QString &propName,
-                               QObject *receiver, const char *slotName);
 
     void uiUpdateProxySettings(const ProxyInfo &info);
     void uiRequestLoginDetails();
@@ -129,7 +127,6 @@ private:
     QObject *selectedNumberButton;
     QObject *regNumberSelector;
     QObject *ciSelector;
-    QObject *dialPage;
     QObject *statusBanner;
     QObject *inboxDetails;
     QObject *smsPage;
